@@ -41,6 +41,7 @@ import time
 import subprocess
 import platform
 import sys
+import chardet
 
 try:
     import json
@@ -474,7 +475,7 @@ def free_space(path):
         sectors, bytes, free, total = map(long, win32file.GetDiskFreeSpace(path))
         return (free * sectors * bytes)
     else:
-        disk_data = os.statvfs(path)
+        disk_data = os.statvfs(path.encode("utf8"))
         block_size = disk_data.f_bsize
         return disk_data.f_bavail * block_size
 
@@ -560,6 +561,41 @@ def xml_encode(string):
         string = string.replace(char, escape)
     return string
 
+def decode_string(s, encoding="utf8"):
+    """
+    Decodes a string and re-encodes it in utf8.  If it cannot decode using
+    `:param:encoding` then it will try to detect the string encoding and
+    decode it.
+
+    :param s: string to decode
+    :type s: string
+    :keyword encoding: the encoding to use in the decoding
+    :type encoding: string
+
+    """
+
+    try:
+        s = s.decode(encoding).encode("utf8", "ignore")
+    except UnicodeDecodeError:
+        s = s.decode(chardet.detect(s)["encoding"], "ignore").encode("utf8", "ignore")
+    return s
+
+def utf8_encoded(s):
+    """
+    Returns a utf8 encoded string of s
+
+    :param s: (unicode) string to (re-)encode
+    :type s: basestring
+    :returns: a utf8 encoded string of s
+    :rtype: str
+
+    """
+    if isinstance(s, str):
+        s = decode_string(s)
+    elif isinstance(s, unicode):
+        s = s.encode("utf8", "ignore")
+    return s
+
 class VersionSplit(object):
     """
     Used for comparing version numbers.
