@@ -82,7 +82,7 @@ class Torrent(object):
         self.config = ConfigManager("core.conf")
 
         self.rpcserver = component.get("RPCServer")
-       
+
         # This dict holds previous status dicts returned for this torrent
         # We use this to return dicts that only contain changes from the previous
         # {session_id: status_dict, ...}
@@ -90,7 +90,7 @@ class Torrent(object):
         from twisted.internet.task import LoopingCall
         self.prev_status_cleanup_loop = LoopingCall(self.cleanup_prev_status)
         self.prev_status_cleanup_loop.start(10)
-         
+
         # Set the libtorrent handle
         self.handle = handle
         # Set the torrent_id for this torrent
@@ -183,7 +183,7 @@ class Torrent(object):
         # repause it after its done if necessary
         self.forcing_recheck = False
         self.forcing_recheck_paused = False
-        
+
         log.debug("Torrent object created.")
 
     ## Options methods ##
@@ -547,18 +547,18 @@ class Torrent(object):
     def get_status(self, keys, diff=False):
         """
         Returns the status of the torrent based on the keys provided
-        
+
         :param keys: the keys to get the status on
         :type keys: list of str
         :param diff: if True, will return a diff of the changes since the last
         call to get_status based on the session_id
         :type diff: bool
-        
+
         :returns: a dictionary of the status keys and their values
         :rtype: dict
-        
+
         """
-     
+
         # Create the full dictionary
         self.status = self.handle.status()
         if self.handle.has_metadata():
@@ -572,6 +572,13 @@ class Torrent(object):
         if distributed_copies < 0:
             distributed_copies = 0.0
 
+        # Calculate the seeds:peers ratio
+        if self.status.num_incomplete == 0:
+            # Use -1.0 to signify infinity
+            seeds_peers_ratio = -1.0
+        else:
+            seeds_peers_ratio = self.status.num_complete / float(self.status.num_incomplete)
+
         #if you add a key here->add it to core.py STATUS_KEYS too.
         full_status = {
             "active_time": self.status.active_time,
@@ -590,6 +597,8 @@ class Torrent(object):
             "message": self.statusmsg,
             "move_on_completed_path": self.options["move_completed_path"],
             "move_on_completed": self.options["move_completed"],
+            "move_completed_path": self.options["move_completed_path"],
+            "move_completed": self.options["move_completed"],
             "next_announce": self.status.next_announce.seconds,
             "num_peers": self.status.num_peers - self.status.num_seeds,
             "num_seeds": self.status.num_seeds,
@@ -599,6 +608,7 @@ class Torrent(object):
             "remove_at_ratio": self.options["remove_at_ratio"],
             "save_path": self.options["download_location"],
             "seeding_time": self.status.seeding_time,
+            "seeds_peers_ratio": seeds_peers_ratio,
             "seed_rank": self.status.seed_rank,
             "state": self.state,
             "stop_at_ratio": self.options["stop_at_ratio"],
@@ -703,7 +713,7 @@ class Torrent(object):
                     status_dict[key] = full_status[key]
                 elif key in fns:
                     status_dict[key] = fns[key]()
-        
+
         session_id = self.rpcserver.get_session_id()
         if diff:
             if session_id in self.prev_status:
@@ -715,7 +725,7 @@ class Torrent(object):
                             status_diff[key] = value
                     else:
                         status_diff[key] = value
-                
+
                 self.prev_status[session_id] = status_dict
                 return status_diff
 
@@ -793,16 +803,25 @@ class Torrent(object):
 
     def move_storage(self, dest):
         """Move a torrent's storage location"""
-        if not os.path.exists(dest):
+
+        # Attempt to convert utf8 path to unicode
+        # Note: Inconsistent encoding for 'dest', needs future investigation
+        try:
+           dest_u = unicode(dest, "utf-8")
+        except TypeError:
+           # String is already unicode
+           dest_u = dest
+
+        if not os.path.exists(dest_u):
             try:
                 # Try to make the destination path if it doesn't exist
-                os.makedirs(dest)
+                os.makedirs(dest_u)
             except IOError, e:
                 log.exception(e)
-                log.error("Could not move storage for torrent %s since %s does not exist and could not create the directory.", self.torrent_id, dest)
+                log.error("Could not move storage for torrent %s since %s does not exist and could not create the directory.", self.torrent_id, dest_u)
                 return False
         try:
-            self.handle.move_storage(dest.encode("utf8"))
+            self.handle.move_storage(dest_u)
         except:
             return False
 
@@ -889,8 +908,8 @@ class Torrent(object):
             log.error("Attempting to rename a folder with an invalid folder name: %s", new_folder)
             return
 
-        if new_folder[-1:] != "/":
-            new_folder += "/"
+        # Make sure the new folder path is nice and has a trailing slash
+        new_folder = os.path.normpath(new_folder) + "/"
 
         wait_on_folder = (folder, new_folder, [])
         for f in self.get_files():
@@ -899,12 +918,12 @@ class Torrent(object):
                 wait_on_folder[2].append(f["index"])
                 self.handle.rename_file(f["index"], f["path"].replace(folder, new_folder, 1).encode("utf-8"))
         self.waiting_on_folder_rename.append(wait_on_folder)
-        
+
     def cleanup_prev_status(self):
         """
         This method gets called to check the validity of the keys in the prev_status
         dict.  If the key is no longer valid, the dict will be deleted.
-        
+
         """
         for key in self.prev_status.keys():
             if not self.rpcserver.is_session_valid(key):
