@@ -160,7 +160,7 @@ class ConsoleUI(component.Component):
         # Set the interactive flag to indicate where we should print the output
         self.interactive = True
         if args:
-            args = args[0]
+            args = ' '.join(args)
             self.interactive = False
 
         # Try to connect to the localhost daemon
@@ -194,8 +194,13 @@ class ConsoleUI(component.Component):
             import curses.wrapper
             curses.wrapper(self.run)
         elif self.interactive and deluge.common.windows_check():
-            print "You cannot run the deluge-console in interactive mode in Windows.\
-            Please use commands from the command line, eg: deluge-console config;help;exit"
+            print """\nDeluge-console does not run in interactive mode on Windows. \n
+Please use commands from the command line, eg:\n
+    deluge-console.exe help
+    deluge-console.exe info
+    deluge-console.exe "add --help"
+    deluge-console.exe "add -p c:\\mytorrents c:\\new.torrent"
+            """
         else:
             reactor.run()
 
@@ -270,7 +275,7 @@ class ConsoleUI(component.Component):
         if self.interactive:
             self.screen.add_line(line, not self.batch_write)
         else:
-            print(colors.strip_colors(line))
+            print(colors.strip_colors(line.encode("utf-8")))
 
     def do_command(self, cmd):
         """
