@@ -41,10 +41,14 @@ import gettext
 import gobject
 import base64
 import os
+from urlparse import urljoin
 
 import pkg_resources
 
+import twisted.web.client
+import twisted.web.error
 from deluge.ui.client import client
+from deluge.httpdownloader import download_file
 import deluge.component as component
 import listview
 from deluge.configmanager import ConfigManager
@@ -651,14 +655,22 @@ class AddTorrentDialog(component.Component):
             dialog.destroy()
 
         def on_download_fail(result):
-            log.debug("Download failed: %s", result)
-            dialog.destroy()
-            dialogs.ErrorDialog(_("Download Failed"), _("Failed to download : %s" % url), details=result.getErrorMessage(), parent=self.dialog).run()
+            if result.check(twisted.web.error.PageRedirect):
+                new_url = urljoin(url, result.getErrorMessage().split(" to ")[1])
+                result = download_file(new_url, tmp_file, on_part)
+                result.addCallbacks(on_download_success, on_download_fail)
+            elif result.check(twisted.web.client.PartialDownloadError):
+                result = download_file(url, tmp_file, on_part, allow_compression=False)
+                result.addCallbacks(on_download_success, on_download_fail)
+            else:
+                log.debug("Download failed: %s", result)
+                dialog.destroy()
+                dialogs.ErrorDialog(_("Download Failed"), _("Failed to download : %s" % url),
+                                    details=result.getErrorMessage(), parent=self.dialog).run()
+            return result
 
-        import deluge.httpdownloader
-        d = deluge.httpdownloader.download_file(url, tmp_file, on_part)
-        d.addCallback(on_download_success)
-        d.addErrback(on_download_fail)
+        d = download_file(url, tmp_file, on_part)
+        d.addCallbacks(on_download_success, on_download_fail)
 
     def _on_button_hash_clicked(self, widget):
         log.debug("_on_button_hash_clicked")
