@@ -50,13 +50,29 @@ import common
 
 from deluge.log import LOG as log
 
+def _(message): return message
+
+TRANSLATE = {
+    "Do Not Download": _("Do Not Download"),
+    "Normal Priority": _("Normal Priority"),
+    "High Priority": _("High Priority"),
+    "Highest Priority": _("Highest Priority"),
+}
+
+del _
+
+def _t(text):
+    if text in TRANSLATE:
+        text = TRANSLATE[text]
+    return _(text)
+
 def cell_priority(column, cell, model, row, data):
     if model.get_value(row, 5) == -1:
         # This is a folder, so lets just set it blank for now
         cell.set_property("text", "")
         return
     priority = model.get_value(row, data)
-    cell.set_property("text", deluge.common.FILE_PRIORITY[priority])
+    cell.set_property("text", _t(deluge.common.FILE_PRIORITY[priority]))
 
 def cell_priority_icon(column, cell, model, row, data):
     if model.get_value(row, 5) == -1:
@@ -65,7 +81,7 @@ def cell_priority_icon(column, cell, model, row, data):
         return
     priority = model.get_value(row, data)
     if deluge.common.FILE_PRIORITY[priority] == "Do Not Download":
-        cell.set_property("stock-id", gtk.STOCK_STOP)
+        cell.set_property("stock-id", gtk.STOCK_NO)
     elif deluge.common.FILE_PRIORITY[priority] == "Normal Priority":
         cell.set_property("stock-id", gtk.STOCK_YES)
     elif deluge.common.FILE_PRIORITY[priority] == "High Priority":
@@ -161,6 +177,8 @@ class FilesTab(Tab):
         column.set_resizable(True)
         column.set_expand(False)
         column.set_min_width(100)
+        # Bugfix: Last column needs max_width set to stop scrollbar appearing
+        column.set_max_width(200)
         column.set_reorderable(True)
         self.listview.append_column(column)
 
@@ -435,7 +453,11 @@ class FilesTab(Tab):
 
                 row = self.treestore.iter_next(row)
 
-            value = (float(bytes) / float(self.treestore[parent][1])) * 100
+            try:
+                value = (float(bytes) / float(self.treestore[parent][1])) * 100
+            except ZeroDivisionError:
+                # Catch the unusal error found when moving folders around
+                value = 0
             self.treestore[parent][3] = value
             self.treestore[parent][2] = "%.2f%%" % value
             return bytes
